===============================
Current source density analysis
===============================

.. automodule:: elephant.current_source_density

Keywords
--------
LFP, CSD, multielectrode, Laminar electrode, Barrel cortex.


Citation Policy
---------------
See `current_source_density_src/README.md
<https://github.com/NeuralEnsemble/elephant/blob/master/elephant/
current_source_density_src/README.md>`_


Author Contributions
--------------------
- Chaitanya Chintaluri (CC)
- Espen Hagen (EH)
- Michał Czerwinski (MC)

EH implemented the iCSD methods and StandardCSD.
CC implemented the kCSD methods, kCSD1D (MC and CC).
CC and EH developed the interface to Elephant.
